<?php
namespace Aelia\WC\CurrencySwitcher\AffiliateWP;
if(!defined('ABSPATH')) { exit; } // Exit ifaccessed directly

/**
 * Handles the settings for the AffiliateWP Integration.
 *
 * @since 1.0.14.200729
 */
class Settings extends \Aelia\WC\Settings {
	/*** Settings Key ***/
	// @var string The key to identify plugin settings amongst WP options.
	const SETTINGS_KEY = 'wc_aelia_cs_affiliatewp';

	protected static $text_domain = Definitions::TEXT_DOMAIN;

	/*** Settings fields ***/
	/**
	 * Class constructor.
	 */
	public function __construct($settings_key = self::SETTINGS_KEY,
															$text_domain = Definitions::TEXT_DOMAIN,
															\Aelia\WC\Settings_Renderer $renderer = null) {
		self::$text_domain = $text_domain;

		// Add Settings to the AffiliateWP settings pages
		add_filter('affwp_settings_tabs', array($this, 'affwp_settings_tabs'), 10);
		add_filter('affwp_settings', array($this, 'affwp_settings'), 10);

	}

	/**
	 * Adds a tab to the Settings section of AffiliateWP. The tab will contain the
	 * settings for this integration.
	 *
	 * @param array $tabs
	 * @return array
	 */
	public function affwp_settings_tabs($tabs) {
		$tabs['currency_switcher'] = __('Aelia Currency Switcher Integration', 'wc-aelia-eu-vat-assistant');
		return $tabs;
	}

	/**
	 * Adds the settings used by this integration to the AffiliateWP settings.
	 *
	 * @param array $settings
	 * @return array
	 */
	public function affwp_settings($settings) {
		$settings['currency_switcher'] = array(
			'currency_switcher_integration_about' => array(
				'name' => '<strong>' . __('Aelia Currency Switcher Integration', 'wc-aelia-eu-vat-assistant') . '</strong>',
				'desc' => __('This section allows to configure the settings for the integration with the Aelia Currency Switcher.', 'wc-aelia-eu-vat-assistant'),
				'type' => 'descriptive_text',
			),
			'currency_switcher_integration_debug_mode' => array(
				'name' => __('Enable Debug Mode', 'wc-aelia-eu-vat-assistant'),
				'desc' => __('When the debug mode is enabled, the Aelia Currency Switcher integration will generate a detailed log of all the operations it performs.', 'wc-aelia-eu-vat-assistant') .
									' ' .
									__('This can be useful during the troubleshooting of issues that could affect the calculation of commissions.', 'wc-aelia-eu-vat-assistant'),
				'type' => 'checkbox',
			),
		);
		return $settings;
	}

	/**
	 * Indicates if the debug mode is enabled.
	 *
	 * @return bool
	 */
	public static function debug_mode() {
		return function_exists('affiliate_wp') && (affiliate_wp()->settings->get('currency_switcher_integration_debug_mode', false));
	}
}
