<?php
namespace Aelia\WC\CurrencySwitcher\AffiliateWP;
if(!defined('ABSPATH')) { exit; } // Exit if accessed directly

require_once('lib/classes/definitions/definitions.php');

use Aelia\WC\Aelia_Plugin;
use Aelia\WC\CurrencySwitcher\AffiliateWP\Settings;
use Aelia\WC\CurrencySwitcher\AffiliateWP\Messages;

/**
 * Main plugin class.
 **/
class Aelia_CS_AffiliateWP extends Aelia_Plugin {
	public static $version = '1.1.15.220704';

	public static $plugin_slug = Definitions::PLUGIN_SLUG;
	public static $text_domain = Definitions::TEXT_DOMAIN;
	public static $plugin_name = 'AffiliateWP integration for WooCommerce Currency Switcher';

	/**
	 * The slug to be used to check for updates has to match the name of the ZIP
	 * file generated for the plugin (without extension). This will allow the
	 * Update Server to be able to find a match.
	 *
	 * @var string
	 * @since 1.0.5.170424
	 */
	public static $slug_for_update_check = 'woocommerce-currency-switcher-affiliatewp-integration';

	/**
	 * Factory method.
	 */
	public static function factory() {
		// Load Composer autoloader
		require_once(__DIR__ . '/vendor/autoload.php');

		$settings_controller = new Settings();
		$messages_controller = new Messages(self::$text_domain);

		$class = get_called_class();
		return new $class($settings_controller, $messages_controller);
	}

	/**
	 * Constructor.
	 *
	 * @param \Aelia\WC\Settings settings_controller The controller that will handle
	 * the plugin settings.
	 * @param \Aelia\WC\Messages messages_controller The controller that will handle
	 * the messages produced by the plugin.
	 */
	public function __construct($settings_controller = null,
															$messages_controller = null) {
		// Load Composer autoloader
		require_once(__DIR__ . '/vendor/autoload.php');
		parent::__construct($settings_controller, $messages_controller);
	}

	/**
	 * Sets the hooks required by the plugin.
	 */
	protected function set_hooks() {
		parent::set_hooks();

		// Add your own hooks here
	}

	/**
	 * Performs operation when all plugins have been loaded.
	 *
	 * @since 1.0.1.150518
	 */
	public function plugins_loaded() {
		$this->get_logger();
		parent::plugins_loaded();

		// Initialise the integration with AffiliateWP
		AffiliateWP_Integration::instance();
	}

	/**
	 * Allows the plugin to register itself for automatic updates.
	 *
	 * @param array The array of the plugins to update, structured as follows:
	 * array(
	 *   'free' => <Array of free plugins>,
	 *   'premium' => <Array of premium plugins, which require licence activation>,
	 * )
	 * @return array The array of plugins to update, with the details of this
	 * plugin added to it.
	 * @since 1.0.4.170104
	 */
	public function wc_aelia_afc_register_plugins_to_update(array $plugins_to_update) {
		// Add this plugins to the list of the plugins to update automatically
		$plugins_to_update['free'][self::$plugin_slug] = $this;
		return $plugins_to_update;
	}

	/**
	 * Indicates if the plugin's debug mode is active. This method must be
	 * overridden by descendant classes.
	 *
	 * @return bool
	 * @since 1.0.12.200505
	 */
	public function debug_mode() {
		return apply_filters(self::$plugin_slug . '_debug_mode', Settings::debug_mode());
	}
}

$GLOBALS[Aelia_CS_AffiliateWP::$plugin_slug] = Aelia_CS_AffiliateWP::factory();
